import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface LogsMetricConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the log-based metric. This field can't be updated after creation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html#name LogsMetric#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html#compute LogsMetric#compute}
     *
     * @stability stable
     */
    readonly compute: LogsMetricCompute[];
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html#filter LogsMetric#filter}
     *
     * @stability stable
     */
    readonly filter: LogsMetricFilter[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html#group_by LogsMetric#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: LogsMetricGroupBy[];
}
/**
 * @stability stable
 */
export interface LogsMetricCompute {
    /**
     * The type of aggregation to use. This field can't be updated after creation. Valid values are `count`, `distribution`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html#aggregation_type LogsMetric#aggregation_type}
     *
     * @stability stable
     */
    readonly aggregationType: string;
    /**
     * The path to the value the log-based metric will aggregate on (only used if the aggregation type is a "distribution").
     *
     * This field can't be updated after creation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html#path LogsMetric#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface LogsMetricFilter {
    /**
     * The search query - following the log search syntax.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html#query LogsMetric#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface LogsMetricGroupBy {
    /**
     * The path to the value the log-based metric will be aggregated over.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html#path LogsMetric#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Name of the tag that gets created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html#tag_name LogsMetric#tag_name}
     *
     * @stability stable
     */
    readonly tagName: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html datadog_logs_metric}.
 *
 * @stability stable
 */
export declare class LogsMetric extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/logs_metric.html datadog_logs_metric} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LogsMetricConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _compute;
    /**
     * @stability stable
     */
    get compute(): LogsMetricCompute[];
    /**
     * @stability stable
     */
    set compute(value: LogsMetricCompute[]);
    /**
     * @stability stable
     */
    get computeInput(): LogsMetricCompute[];
    private _filter;
    /**
     * @stability stable
     */
    get filter(): LogsMetricFilter[];
    /**
     * @stability stable
     */
    set filter(value: LogsMetricFilter[]);
    /**
     * @stability stable
     */
    get filterInput(): LogsMetricFilter[];
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): LogsMetricGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: LogsMetricGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): LogsMetricGroupBy[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
