import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MonitorConfig extends cdktf.TerraformMetaArguments {
    /**
     * A boolean indicating whether or not to include a list of log values which triggered the alert.
     *
     * This is only used by log monitors. Defaults to `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#enable_logs_sample Monitor#enable_logs_sample}
     *
     * @stability stable
     */
    readonly enableLogsSample?: boolean;
    /**
     * A message to include with a re-notification. Supports the `@username` notification allowed elsewhere.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#escalation_message Monitor#escalation_message}
     *
     * @stability stable
     */
    readonly escalationMessage?: string;
    /**
     * (Only applies to metric alert) Time (in seconds) to delay evaluation, as a non-negative integer.
     *
     * For example, if the value is set to `300` (5min), the `timeframe` is set to `last_5m` and the time is 7:00, the monitor will evaluate data from 6:50 to 6:55. This is useful for AWS CloudWatch and other backfilled metrics to ensure the monitor will always have data during evaluation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#evaluation_delay Monitor#evaluation_delay}
     *
     * @stability stable
     */
    readonly evaluationDelay?: number;
    /**
     * A boolean indicating whether this monitor can be deleted even if it’s referenced by other resources (e.g. SLO, composite monitor).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#force_delete Monitor#force_delete}
     *
     * @stability stable
     */
    readonly forceDelete?: boolean;
    /**
     * Whether or not to trigger one alert if any source breaches a threshold.
     *
     * This is only used by log monitors. Defaults to `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#groupby_simple_monitor Monitor#groupby_simple_monitor}
     *
     * @stability stable
     */
    readonly groupbySimpleMonitor?: boolean;
    /**
     * A boolean indicating whether notifications from this monitor automatically insert its triggering tags into the title. Defaults to `true`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#include_tags Monitor#include_tags}
     *
     * @stability stable
     */
    readonly includeTags?: boolean;
    /**
     * A boolean indicating whether changes to to this monitor should be restricted to the creator or admins.
     *
     * Defaults to `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#locked Monitor#locked}
     *
     * @stability stable
     */
    readonly locked?: boolean;
    /**
     * A message to include with notifications for this monitor.
     *
     * Email notifications can be sent to specific users by using the same `@username` notation as events.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#message Monitor#message}
     *
     * @stability stable
     */
    readonly message: string;
    /**
     * Name of Datadog monitor.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#name Monitor#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Time (in seconds) to allow a host to boot and applications to fully start before starting the evaluation of monitor results.
     *
     * Should be a non negative integer. Defaults to `300`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#new_host_delay Monitor#new_host_delay}
     *
     * @stability stable
     */
    readonly newHostDelay?: number;
    /**
     * The number of minutes before a monitor will notify when data stops reporting. Provider defaults to 10 minutes.
     *
     * We recommend at least 2x the monitor timeframe for metric alerts or 2 minutes for service checks.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#no_data_timeframe Monitor#no_data_timeframe}
     *
     * @stability stable
     */
    readonly noDataTimeframe?: number;
    /**
     * A boolean indicating whether tagged users will be notified on changes to this monitor. Defaults to `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#notify_audit Monitor#notify_audit}
     *
     * @stability stable
     */
    readonly notifyAudit?: boolean;
    /**
     * A boolean indicating whether this monitor will notify when data stops reporting. Defaults to `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#notify_no_data Monitor#notify_no_data}
     *
     * @stability stable
     */
    readonly notifyNoData?: boolean;
    /**
     * Integer from 1 (high) to 5 (low) indicating alert severity.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#priority Monitor#priority}
     *
     * @stability stable
     */
    readonly priority?: number;
    /**
     * The monitor query to notify on.
     *
     * Note this is not the same query you see in the UI and the syntax is different depending on the monitor type, please see the [API Reference](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor) for details. `terraform plan` will validate query contents unless `validate` is set to `false`.
     *
     * *Note:** APM latency data is now available as Distribution Metrics. Existing monitors have been migrated automatically but all terraformed monitors can still use the existing metrics. We strongly recommend updating monitor definitions to query the new metrics. To learn more, or to see examples of how to update your terraform definitions to utilize the new distribution metrics, see the [detailed doc](https://docs.datadoghq.com/tracing/guide/ddsketch_trace_metrics/).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#query Monitor#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * The number of minutes after the last notification before a monitor will re-notify on the current status.
     *
     * It will only re-notify if it's not resolved.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#renotify_interval Monitor#renotify_interval}
     *
     * @stability stable
     */
    readonly renotifyInterval?: number;
    /**
     * A boolean indicating whether this monitor needs a full window of data before it's evaluated.
     *
     * We highly recommend you set this to `false` for sparse metrics, otherwise some evaluations will be skipped. Default: `true` for `on average`, `at all times` and `in total` aggregation. `false` otherwise.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#require_full_window Monitor#require_full_window}
     *
     * @stability stable
     */
    readonly requireFullWindow?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#restricted_roles Monitor#restricted_roles}.
     *
     * @stability stable
     */
    readonly restrictedRoles?: string[];
    /**
     * A list of tags to associate with your monitor.
     *
     * This can help you categorize and filter monitors in the manage monitors page of the UI. Note: it's not currently possible to filter by these tags when querying via the API
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#tags Monitor#tags}
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * The number of hours of the monitor not reporting data before it will automatically resolve from a triggered state.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#timeout_h Monitor#timeout_h}
     *
     * @stability stable
     */
    readonly timeoutH?: number;
    /**
     * The type of the monitor.
     *
     * The mapping from these types to the types found in the Datadog Web UI can be found in the Datadog API [documentation page](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor). Note: The monitor type cannot be changed after a monitor is created. Valid values are `composite`, `event alert`, `log alert`, `metric alert`, `process alert`, `query alert`, `rum alert`, `service check`, `synthetics alert`, `trace-analytics alert`, `slo alert`, `event-v2 alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#type Monitor#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * If set to `false`, skip the validation call done during plan.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#validate Monitor#validate}
     *
     * @stability stable
     */
    readonly validate?: boolean;
    /**
     * monitor_threshold_windows block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#monitor_threshold_windows Monitor#monitor_threshold_windows}
     *
     * @stability stable
     */
    readonly monitorThresholdWindows?: MonitorMonitorThresholdWindows[];
    /**
     * monitor_thresholds block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#monitor_thresholds Monitor#monitor_thresholds}
     *
     * @stability stable
     */
    readonly monitorThresholds?: MonitorMonitorThresholds[];
}
/**
 * @stability stable
 */
export interface MonitorMonitorThresholdWindows {
    /**
     * Describes how long an anomalous metric must be normal before the alert recovers.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#recovery_window Monitor#recovery_window}
     *
     * @stability stable
     */
    readonly recoveryWindow?: string;
    /**
     * Describes how long a metric must be anomalous before an alert triggers.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#trigger_window Monitor#trigger_window}
     *
     * @stability stable
     */
    readonly triggerWindow?: string;
}
/**
 * @stability stable
 */
export interface MonitorMonitorThresholds {
    /**
     * The monitor `CRITICAL` threshold. Must be a number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#critical Monitor#critical}
     *
     * @stability stable
     */
    readonly critical?: string;
    /**
     * The monitor `CRITICAL` recovery threshold. Must be a number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#critical_recovery Monitor#critical_recovery}
     *
     * @stability stable
     */
    readonly criticalRecovery?: string;
    /**
     * The monitor `OK` threshold. Must be a number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#ok Monitor#ok}
     *
     * @stability stable
     */
    readonly ok?: string;
    /**
     * The monitor `UNKNOWN` threshold. Must be a number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#unknown Monitor#unknown}
     *
     * @stability stable
     */
    readonly unknown?: string;
    /**
     * The monitor `WARNING` threshold. Must be a number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#warning Monitor#warning}
     *
     * @stability stable
     */
    readonly warning?: string;
    /**
     * The monitor `WARNING` recovery threshold. Must be a number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html#warning_recovery Monitor#warning_recovery}
     *
     * @stability stable
     */
    readonly warningRecovery?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html datadog_monitor}.
 *
 * @stability stable
 */
export declare class Monitor extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/monitor.html datadog_monitor} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MonitorConfig);
    private _enableLogsSample?;
    /**
     * @stability stable
     */
    get enableLogsSample(): boolean;
    /**
     * @stability stable
     */
    set enableLogsSample(value: boolean);
    /**
     * @stability stable
     */
    resetEnableLogsSample(): void;
    /**
     * @stability stable
     */
    get enableLogsSampleInput(): boolean | undefined;
    private _escalationMessage?;
    /**
     * @stability stable
     */
    get escalationMessage(): string;
    /**
     * @stability stable
     */
    set escalationMessage(value: string);
    /**
     * @stability stable
     */
    resetEscalationMessage(): void;
    /**
     * @stability stable
     */
    get escalationMessageInput(): string | undefined;
    private _evaluationDelay?;
    /**
     * @stability stable
     */
    get evaluationDelay(): number;
    /**
     * @stability stable
     */
    set evaluationDelay(value: number);
    /**
     * @stability stable
     */
    resetEvaluationDelay(): void;
    /**
     * @stability stable
     */
    get evaluationDelayInput(): number | undefined;
    private _forceDelete?;
    /**
     * @stability stable
     */
    get forceDelete(): boolean;
    /**
     * @stability stable
     */
    set forceDelete(value: boolean);
    /**
     * @stability stable
     */
    resetForceDelete(): void;
    /**
     * @stability stable
     */
    get forceDeleteInput(): boolean | undefined;
    private _groupbySimpleMonitor?;
    /**
     * @stability stable
     */
    get groupbySimpleMonitor(): boolean;
    /**
     * @stability stable
     */
    set groupbySimpleMonitor(value: boolean);
    /**
     * @stability stable
     */
    resetGroupbySimpleMonitor(): void;
    /**
     * @stability stable
     */
    get groupbySimpleMonitorInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _includeTags?;
    /**
     * @stability stable
     */
    get includeTags(): boolean;
    /**
     * @stability stable
     */
    set includeTags(value: boolean);
    /**
     * @stability stable
     */
    resetIncludeTags(): void;
    /**
     * @stability stable
     */
    get includeTagsInput(): boolean | undefined;
    private _locked?;
    /**
     * @stability stable
     */
    get locked(): boolean;
    /**
     * @stability stable
     */
    set locked(value: boolean);
    /**
     * @stability stable
     */
    resetLocked(): void;
    /**
     * @stability stable
     */
    get lockedInput(): boolean | undefined;
    private _message;
    /**
     * @stability stable
     */
    get message(): string;
    /**
     * @stability stable
     */
    set message(value: string);
    /**
     * @stability stable
     */
    get messageInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _newHostDelay?;
    /**
     * @stability stable
     */
    get newHostDelay(): number;
    /**
     * @stability stable
     */
    set newHostDelay(value: number);
    /**
     * @stability stable
     */
    resetNewHostDelay(): void;
    /**
     * @stability stable
     */
    get newHostDelayInput(): number | undefined;
    private _noDataTimeframe?;
    /**
     * @stability stable
     */
    get noDataTimeframe(): number;
    /**
     * @stability stable
     */
    set noDataTimeframe(value: number);
    /**
     * @stability stable
     */
    resetNoDataTimeframe(): void;
    /**
     * @stability stable
     */
    get noDataTimeframeInput(): number | undefined;
    private _notifyAudit?;
    /**
     * @stability stable
     */
    get notifyAudit(): boolean;
    /**
     * @stability stable
     */
    set notifyAudit(value: boolean);
    /**
     * @stability stable
     */
    resetNotifyAudit(): void;
    /**
     * @stability stable
     */
    get notifyAuditInput(): boolean | undefined;
    private _notifyNoData?;
    /**
     * @stability stable
     */
    get notifyNoData(): boolean;
    /**
     * @stability stable
     */
    set notifyNoData(value: boolean);
    /**
     * @stability stable
     */
    resetNotifyNoData(): void;
    /**
     * @stability stable
     */
    get notifyNoDataInput(): boolean | undefined;
    private _priority?;
    /**
     * @stability stable
     */
    get priority(): number;
    /**
     * @stability stable
     */
    set priority(value: number);
    /**
     * @stability stable
     */
    resetPriority(): void;
    /**
     * @stability stable
     */
    get priorityInput(): number | undefined;
    private _query;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string;
    private _renotifyInterval?;
    /**
     * @stability stable
     */
    get renotifyInterval(): number;
    /**
     * @stability stable
     */
    set renotifyInterval(value: number);
    /**
     * @stability stable
     */
    resetRenotifyInterval(): void;
    /**
     * @stability stable
     */
    get renotifyIntervalInput(): number | undefined;
    private _requireFullWindow?;
    /**
     * @stability stable
     */
    get requireFullWindow(): boolean;
    /**
     * @stability stable
     */
    set requireFullWindow(value: boolean);
    /**
     * @stability stable
     */
    resetRequireFullWindow(): void;
    /**
     * @stability stable
     */
    get requireFullWindowInput(): boolean | undefined;
    private _restrictedRoles?;
    /**
     * @stability stable
     */
    get restrictedRoles(): string[];
    /**
     * @stability stable
     */
    set restrictedRoles(value: string[]);
    /**
     * @stability stable
     */
    resetRestrictedRoles(): void;
    /**
     * @stability stable
     */
    get restrictedRolesInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): string[];
    /**
     * @stability stable
     */
    set tags(value: string[]);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): string[] | undefined;
    private _timeoutH?;
    /**
     * @stability stable
     */
    get timeoutH(): number;
    /**
     * @stability stable
     */
    set timeoutH(value: number);
    /**
     * @stability stable
     */
    resetTimeoutH(): void;
    /**
     * @stability stable
     */
    get timeoutHInput(): number | undefined;
    private _type;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string;
    private _validate?;
    /**
     * @stability stable
     */
    get validate(): boolean;
    /**
     * @stability stable
     */
    set validate(value: boolean);
    /**
     * @stability stable
     */
    resetValidate(): void;
    /**
     * @stability stable
     */
    get validateInput(): boolean | undefined;
    private _monitorThresholdWindows?;
    /**
     * @stability stable
     */
    get monitorThresholdWindows(): MonitorMonitorThresholdWindows[];
    /**
     * @stability stable
     */
    set monitorThresholdWindows(value: MonitorMonitorThresholdWindows[]);
    /**
     * @stability stable
     */
    resetMonitorThresholdWindows(): void;
    /**
     * @stability stable
     */
    get monitorThresholdWindowsInput(): MonitorMonitorThresholdWindows[] | undefined;
    private _monitorThresholds?;
    /**
     * @stability stable
     */
    get monitorThresholds(): MonitorMonitorThresholds[];
    /**
     * @stability stable
     */
    set monitorThresholds(value: MonitorMonitorThresholds[]);
    /**
     * @stability stable
     */
    resetMonitorThresholds(): void;
    /**
     * @stability stable
     */
    get monitorThresholdsInput(): MonitorMonitorThresholds[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
