import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SyntheticsGlobalVariableConfig extends cdktf.TerraformMetaArguments {
    /**
     * Description of the global variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#description SyntheticsGlobalVariable#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Synthetics global variable name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#name SyntheticsGlobalVariable#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Id of the Synthetics test to use for a variable from test.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#parse_test_id SyntheticsGlobalVariable#parse_test_id}
     *
     * @stability stable
     */
    readonly parseTestId?: string;
    /**
     * Sets the variable as secure. Defaults to `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#secure SyntheticsGlobalVariable#secure}
     *
     * @stability stable
     */
    readonly secure?: boolean;
    /**
     * A list of tags to associate with your synthetics global variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#tags SyntheticsGlobalVariable#tags}
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * The value of the global variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#value SyntheticsGlobalVariable#value}
     *
     * @stability stable
     */
    readonly value: string;
    /**
     * parse_test_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#parse_test_options SyntheticsGlobalVariable#parse_test_options}
     *
     * @stability stable
     */
    readonly parseTestOptions?: SyntheticsGlobalVariableParseTestOptions[];
}
/**
 * @stability stable
 */
export interface SyntheticsGlobalVariableParseTestOptionsParser {
    /**
     * Type of parser to extract the value. Valid values are `raw`, `json_path`, `regex`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#type SyntheticsGlobalVariable#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Value for the parser to use, required for type `json_path` or `regex`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#value SyntheticsGlobalVariable#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface SyntheticsGlobalVariableParseTestOptions {
    /**
     * Required when type = `http_header`. Defines the header to use to extract the value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#field SyntheticsGlobalVariable#field}
     *
     * @stability stable
     */
    readonly field?: string;
    /**
     * Defines the source to use to extract the value. Valid values are `http_body`, `http_header`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#type SyntheticsGlobalVariable#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * parser block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html#parser SyntheticsGlobalVariable#parser}
     *
     * @stability stable
     */
    readonly parser: SyntheticsGlobalVariableParseTestOptionsParser[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html datadog_synthetics_global_variable}.
 *
 * @stability stable
 */
export declare class SyntheticsGlobalVariable extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_global_variable.html datadog_synthetics_global_variable} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SyntheticsGlobalVariableConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _parseTestId?;
    /**
     * @stability stable
     */
    get parseTestId(): string;
    /**
     * @stability stable
     */
    set parseTestId(value: string);
    /**
     * @stability stable
     */
    resetParseTestId(): void;
    /**
     * @stability stable
     */
    get parseTestIdInput(): string | undefined;
    private _secure?;
    /**
     * @stability stable
     */
    get secure(): boolean;
    /**
     * @stability stable
     */
    set secure(value: boolean);
    /**
     * @stability stable
     */
    resetSecure(): void;
    /**
     * @stability stable
     */
    get secureInput(): boolean | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): string[];
    /**
     * @stability stable
     */
    set tags(value: string[]);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): string[] | undefined;
    private _value;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    get valueInput(): string;
    private _parseTestOptions?;
    /**
     * @stability stable
     */
    get parseTestOptions(): SyntheticsGlobalVariableParseTestOptions[];
    /**
     * @stability stable
     */
    set parseTestOptions(value: SyntheticsGlobalVariableParseTestOptions[]);
    /**
     * @stability stable
     */
    resetParseTestOptions(): void;
    /**
     * @stability stable
     */
    get parseTestOptionsInput(): SyntheticsGlobalVariableParseTestOptions[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
