import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SyntheticsTestConfig extends cdktf.TerraformMetaArguments {
    /**
     * Array with the different device IDs used to run the test (only for `browser` tests).
     *
     * Valid values are `laptop_large`, `tablet`, `mobile_small`, `chrome.laptop_large`, `chrome.tablet`, `chrome.mobile_small`, `firefox.laptop_large`, `firefox.tablet`, `firefox.mobile_small`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#device_ids SyntheticsTest#device_ids}
     *
     * @stability stable
     */
    readonly deviceIds?: string[];
    /**
     * Array of locations used to run the test. Refer to [Datadog documentation](https://docs.datadoghq.com/synthetics/api_test/#request) for available locations (e.g. `aws:eu-central-1`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#locations SyntheticsTest#locations}
     *
     * @stability stable
     */
    readonly locations: string[];
    /**
     * A message to include with notifications for this synthetics test.
     *
     * Email notifications can be sent to specific users by using the same `@username` notation as events.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#message SyntheticsTest#message}
     *
     * @stability stable
     */
    readonly message?: string;
    /**
     * Name of Datadog synthetics test.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#name SyntheticsTest#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Header name and value map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_headers SyntheticsTest#request_headers}
     *
     * @stability stable
     */
    readonly requestHeaders?: {
        [key: string]: string;
    };
    /**
     * Query arguments name and value map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_query SyntheticsTest#request_query}
     *
     * @stability stable
     */
    readonly requestQuery?: {
        [key: string]: string;
    };
    /**
     * Cookies to be used for a browser test request, using the [Set-Cookie](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie) syntax.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#set_cookie SyntheticsTest#set_cookie}
     *
     * @stability stable
     */
    readonly setCookie?: string;
    /**
     * Define whether you want to start (`live`) or pause (`paused`) a Synthetic test. Valid values are `live`, `paused`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#status SyntheticsTest#status}
     *
     * @stability stable
     */
    readonly status: string;
    /**
     * The subtype of the Synthetic API test. Defaults to `http`. Valid values are `http`, `ssl`, `tcp`, `dns`, `multi`, `icmp`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#subtype SyntheticsTest#subtype}
     *
     * @stability stable
     */
    readonly subtype?: string;
    /**
     * A list of tags to associate with your synthetics test.
     *
     * This can help you categorize and filter tests in the manage synthetics page of the UI. Default is an empty list (`[]`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#tags SyntheticsTest#tags}
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * Synthetics test type. Valid values are `api`, `browser`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#type SyntheticsTest#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * api_step block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#api_step SyntheticsTest#api_step}
     *
     * @stability stable
     */
    readonly apiStep?: SyntheticsTestApiStep[];
    /**
     * assertion block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#assertion SyntheticsTest#assertion}
     *
     * @stability stable
     */
    readonly assertion?: SyntheticsTestAssertion[];
    /**
     * browser_step block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#browser_step SyntheticsTest#browser_step}
     *
     * @stability stable
     */
    readonly browserStep?: SyntheticsTestBrowserStep[];
    /**
     * browser_variable block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#browser_variable SyntheticsTest#browser_variable}
     *
     * @stability stable
     */
    readonly browserVariable?: SyntheticsTestBrowserVariable[];
    /**
     * config_variable block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#config_variable SyntheticsTest#config_variable}
     *
     * @stability stable
     */
    readonly configVariable?: SyntheticsTestConfigVariable[];
    /**
     * options_list block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#options_list SyntheticsTest#options_list}
     *
     * @stability stable
     */
    readonly optionsList?: SyntheticsTestOptionsList[];
    /**
     * request_basicauth block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_basicauth SyntheticsTest#request_basicauth}
     *
     * @stability stable
     */
    readonly requestBasicauth?: SyntheticsTestRequestBasicauth[];
    /**
     * request_client_certificate block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_client_certificate SyntheticsTest#request_client_certificate}
     *
     * @stability stable
     */
    readonly requestClientCertificate?: SyntheticsTestRequestClientCertificate[];
    /**
     * request_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_definition SyntheticsTest#request_definition}
     *
     * @stability stable
     */
    readonly requestDefinition?: SyntheticsTestRequestDefinition[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStepAssertionTargetjsonpath {
    /**
     * The JSON path to assert.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#jsonpath SyntheticsTest#jsonpath}
     *
     * @stability stable
     */
    readonly jsonpath: string;
    /**
     * The specific operator to use on the path.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#operator SyntheticsTest#operator}
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * Expected matching value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#targetvalue SyntheticsTest#targetvalue}
     *
     * @stability stable
     */
    readonly targetvalue: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStepAssertion {
    /**
     * Assertion operator. **Note** Only some combinations of `type` and `operator` are valid (please refer to [Datadog documentation](https://docs.datadoghq.com/api/latest/synthetics/#create-a-test)).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#operator SyntheticsTest#operator}
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * If assertion type is `header`, this is the header name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#property SyntheticsTest#property}
     *
     * @stability stable
     */
    readonly property?: string;
    /**
     * Expected value. Depends on the assertion type, refer to [Datadog documentation](https://docs.datadoghq.com/api/latest/synthetics/#create-a-test) for details.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#target SyntheticsTest#target}
     *
     * @stability stable
     */
    readonly target?: string;
    /**
     * Type of assertion.
     *
     * **Note** Only some combinations of `type` and `operator` are valid (please refer to [Datadog documentation](https://docs.datadoghq.com/api/latest/synthetics/#create-a-test)). Valid values are `body`, `header`, `statusCode`, `certificate`, `responseTime`, `property`, `recordEvery`, `recordSome`, `tlsVersion`, `minTlsVersion`, `latency`, `packetLossPercentage`, `packetsReceived`, `networkHop`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#type SyntheticsTest#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * targetjsonpath block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#targetjsonpath SyntheticsTest#targetjsonpath}
     *
     * @stability stable
     */
    readonly targetjsonpath?: SyntheticsTestApiStepAssertionTargetjsonpath[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStepExtractedValueParser {
    /**
     * Type of parser for a Synthetics global variable from a synthetics test. Valid values are `raw`, `json_path`, `regex`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#type SyntheticsTest#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Regex or JSON path used for the parser. Not used with type `raw`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#value SyntheticsTest#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStepExtractedValue {
    /**
     * When type is `http_header`, name of the header to use to extract the value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#field SyntheticsTest#field}
     *
     * @stability stable
     */
    readonly field?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#name SyntheticsTest#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Property of the Synthetics Test Response to use for the variable. Valid values are `http_body`, `http_header`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#type SyntheticsTest#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * parser block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#parser SyntheticsTest#parser}
     *
     * @stability stable
     */
    readonly parser: SyntheticsTestApiStepExtractedValueParser[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStepRequestBasicauth {
    /**
     * Password for authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#password SyntheticsTest#password}
     *
     * @stability stable
     */
    readonly password: string;
    /**
     * Username for authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#username SyntheticsTest#username}
     *
     * @stability stable
     */
    readonly username: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStepRequestClientCertificateCert {
    /**
     * Content of the certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#content SyntheticsTest#content}
     *
     * @stability stable
     */
    readonly content: string;
    /**
     * File name for the certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#filename SyntheticsTest#filename}
     *
     * @stability stable
     */
    readonly filename?: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStepRequestClientCertificateKey {
    /**
     * Content of the certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#content SyntheticsTest#content}
     *
     * @stability stable
     */
    readonly content: string;
    /**
     * File name for the certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#filename SyntheticsTest#filename}
     *
     * @stability stable
     */
    readonly filename?: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStepRequestClientCertificate {
    /**
     * cert block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#cert SyntheticsTest#cert}
     *
     * @stability stable
     */
    readonly cert: SyntheticsTestApiStepRequestClientCertificateCert[];
    /**
     * key block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#key SyntheticsTest#key}
     *
     * @stability stable
     */
    readonly key: SyntheticsTestApiStepRequestClientCertificateKey[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStepRequestDefinition {
    /**
     * The request body.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#body SyntheticsTest#body}
     *
     * @stability stable
     */
    readonly body?: string;
    /**
     * DNS server to use for DNS tests (`subtype = "dns"`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#dns_server SyntheticsTest#dns_server}
     *
     * @stability stable
     */
    readonly dnsServer?: string;
    /**
     * DNS server port to use for DNS tests.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#dns_server_port SyntheticsTest#dns_server_port}
     *
     * @stability stable
     */
    readonly dnsServerPort?: number;
    /**
     * Host name to perform the test with.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#host SyntheticsTest#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * The HTTP method. Valid values are `GET`, `POST`, `PATCH`, `PUT`, `DELETE`, `HEAD`, `OPTIONS`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#method SyntheticsTest#method}
     *
     * @stability stable
     */
    readonly method?: string;
    /**
     * Determines whether or not to save the response body.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#no_saving_response_body SyntheticsTest#no_saving_response_body}
     *
     * @stability stable
     */
    readonly noSavingResponseBody?: boolean;
    /**
     * Number of pings to use per test for ICMP tests (`subtype = "icmp"`) between 0 and 10.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#number_of_packets SyntheticsTest#number_of_packets}
     *
     * @stability stable
     */
    readonly numberOfPackets?: number;
    /**
     * Port to use when performing the test.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#port SyntheticsTest#port}
     *
     * @stability stable
     */
    readonly port?: number;
    /**
     * This will turn on a traceroute probe to discover all gateways along the path to the host destination.
     *
     * For ICMP tests (`subtype = "icmp"`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#should_track_hops SyntheticsTest#should_track_hops}
     *
     * @stability stable
     */
    readonly shouldTrackHops?: boolean;
    /**
     * Timeout in seconds for the test. Defaults to `60`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#timeout SyntheticsTest#timeout}
     *
     * @stability stable
     */
    readonly timeout?: number;
    /**
     * The URL to send the request to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#url SyntheticsTest#url}
     *
     * @stability stable
     */
    readonly url?: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestApiStep {
    /**
     * Determines whether or not to continue with test if this step fails.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#allow_failure SyntheticsTest#allow_failure}
     *
     * @stability stable
     */
    readonly allowFailure?: boolean;
    /**
     * Determines whether or not to consider the entire test as failed if this step fails.
     *
     * Can be used only if `allow_failure` is `true`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#is_critical SyntheticsTest#is_critical}
     *
     * @stability stable
     */
    readonly isCritical?: boolean;
    /**
     * The name of the step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#name SyntheticsTest#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Header name and value map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_headers SyntheticsTest#request_headers}
     *
     * @stability stable
     */
    readonly requestHeaders?: {
        [key: string]: string;
    };
    /**
     * Query arguments name and value map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_query SyntheticsTest#request_query}
     *
     * @stability stable
     */
    readonly requestQuery?: {
        [key: string]: string;
    };
    /**
     * The subtype of the Synthetic multistep API test step. Valid values are `http`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#subtype SyntheticsTest#subtype}
     *
     * @stability stable
     */
    readonly subtype?: string;
    /**
     * assertion block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#assertion SyntheticsTest#assertion}
     *
     * @stability stable
     */
    readonly assertion?: SyntheticsTestApiStepAssertion[];
    /**
     * extracted_value block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#extracted_value SyntheticsTest#extracted_value}
     *
     * @stability stable
     */
    readonly extractedValue?: SyntheticsTestApiStepExtractedValue[];
    /**
     * request_basicauth block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_basicauth SyntheticsTest#request_basicauth}
     *
     * @stability stable
     */
    readonly requestBasicauth?: SyntheticsTestApiStepRequestBasicauth[];
    /**
     * request_client_certificate block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_client_certificate SyntheticsTest#request_client_certificate}
     *
     * @stability stable
     */
    readonly requestClientCertificate?: SyntheticsTestApiStepRequestClientCertificate[];
    /**
     * request_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request_definition SyntheticsTest#request_definition}
     *
     * @stability stable
     */
    readonly requestDefinition?: SyntheticsTestApiStepRequestDefinition[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestAssertionTargetjsonpath {
    /**
     * The JSON path to assert.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#jsonpath SyntheticsTest#jsonpath}
     *
     * @stability stable
     */
    readonly jsonpath: string;
    /**
     * The specific operator to use on the path.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#operator SyntheticsTest#operator}
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * Expected matching value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#targetvalue SyntheticsTest#targetvalue}
     *
     * @stability stable
     */
    readonly targetvalue: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestAssertion {
    /**
     * Assertion operator. **Note** Only some combinations of `type` and `operator` are valid (please refer to [Datadog documentation](https://docs.datadoghq.com/api/latest/synthetics/#create-a-test)).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#operator SyntheticsTest#operator}
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * If assertion type is `header`, this is the header name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#property SyntheticsTest#property}
     *
     * @stability stable
     */
    readonly property?: string;
    /**
     * Expected value. Depends on the assertion type, refer to [Datadog documentation](https://docs.datadoghq.com/api/latest/synthetics/#create-a-test) for details.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#target SyntheticsTest#target}
     *
     * @stability stable
     */
    readonly target?: string;
    /**
     * Type of assertion.
     *
     * **Note** Only some combinations of `type` and `operator` are valid (please refer to [Datadog documentation](https://docs.datadoghq.com/api/latest/synthetics/#create-a-test)). Valid values are `body`, `header`, `statusCode`, `certificate`, `responseTime`, `property`, `recordEvery`, `recordSome`, `tlsVersion`, `minTlsVersion`, `latency`, `packetLossPercentage`, `packetsReceived`, `networkHop`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#type SyntheticsTest#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * targetjsonpath block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#targetjsonpath SyntheticsTest#targetjsonpath}
     *
     * @stability stable
     */
    readonly targetjsonpath?: SyntheticsTestAssertionTargetjsonpath[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestBrowserStepParamsVariable {
    /**
     * Example of the extracted variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#example SyntheticsTest#example}
     *
     * @stability stable
     */
    readonly example?: string;
    /**
     * Name of the extracted variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#name SyntheticsTest#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestBrowserStepParams {
    /**
     * Name of the attribute to use for an "assert attribute" step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#attribute SyntheticsTest#attribute}
     *
     * @stability stable
     */
    readonly attribute?: string;
    /**
     * Check type to use for an assertion step.
     *
     * Valid values are `equals`, `notEquals`, `contains`, `notContains`, `startsWith`, `notStartsWith`, `greater`, `lower`, `greaterEquals`, `lowerEquals`, `matchRegex`, `between`, `isEmpty`, `notIsEmpty`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#check SyntheticsTest#check}
     *
     * @stability stable
     */
    readonly check?: string;
    /**
     * Type of click to use for a "click" step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#click_type SyntheticsTest#click_type}
     *
     * @stability stable
     */
    readonly clickType?: string;
    /**
     * Javascript code to use for the step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#code SyntheticsTest#code}
     *
     * @stability stable
     */
    readonly code?: string;
    /**
     * Delay between each key stroke for a "type test" step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#delay SyntheticsTest#delay}
     *
     * @stability stable
     */
    readonly delay?: number;
    /**
     * Element to use for the step, json encoded string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#element SyntheticsTest#element}
     *
     * @stability stable
     */
    readonly element?: string;
    /**
     * Details of the email for an "assert email" step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#email SyntheticsTest#email}
     *
     * @stability stable
     */
    readonly email?: string;
    /**
     * For an "assert download" step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#file SyntheticsTest#file}
     *
     * @stability stable
     */
    readonly file?: string;
    /**
     * Details of the files for an "upload files" step, json encoded string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#files SyntheticsTest#files}
     *
     * @stability stable
     */
    readonly files?: string;
    /**
     * Modifier to use for a "press key" step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#modifiers SyntheticsTest#modifiers}
     *
     * @stability stable
     */
    readonly modifiers?: string[];
    /**
     * ID of the tab to play the subtest.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#playing_tab_id SyntheticsTest#playing_tab_id}
     *
     * @stability stable
     */
    readonly playingTabId?: string;
    /**
     * Request for an API step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#request SyntheticsTest#request}
     *
     * @stability stable
     */
    readonly request?: string;
    /**
     * ID of the Synthetics test to use as subtest.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#subtest_public_id SyntheticsTest#subtest_public_id}
     *
     * @stability stable
     */
    readonly subtestPublicId?: string;
    /**
     * Value of the step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#value SyntheticsTest#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * For "file upload" steps.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#with_click SyntheticsTest#with_click}
     *
     * @stability stable
     */
    readonly withClick?: boolean;
    /**
     * X coordinates for a "scroll step".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#x SyntheticsTest#x}
     *
     * @stability stable
     */
    readonly x?: number;
    /**
     * Y coordinates for a "scroll step".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#y SyntheticsTest#y}
     *
     * @stability stable
     */
    readonly y?: number;
    /**
     * variable block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#variable SyntheticsTest#variable}
     *
     * @stability stable
     */
    readonly variable?: SyntheticsTestBrowserStepParamsVariable[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestBrowserStep {
    /**
     * Determines if the step should be allowed to fail.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#allow_failure SyntheticsTest#allow_failure}
     *
     * @stability stable
     */
    readonly allowFailure?: boolean;
    /**
     * Force update of the "element" parameter for the step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#force_element_update SyntheticsTest#force_element_update}
     *
     * @stability stable
     */
    readonly forceElementUpdate?: boolean;
    /**
     * Name of the step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#name SyntheticsTest#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Used to override the default timeout of a step.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#timeout SyntheticsTest#timeout}
     *
     * @stability stable
     */
    readonly timeout?: number;
    /**
     * Type of the step.
     *
     * Valid values are `assertCurrentUrl`, `assertElementAttribute`, `assertElementContent`, `assertElementPresent`, `assertEmail`, `assertFileDownload`, `assertFromJavascript`, `assertPageContains`, `assertPageLacks`, `click`, `extractFromJavascript`, `extractVariable`, `goToEmailLink`, `goToUrl`, `goToUrlAndMeasureTti`, `hover`, `playSubTest`, `pressKey`, `refresh`, `runApiTest`, `scroll`, `selectOption`, `typeText`, `uploadFiles`, `wait`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#type SyntheticsTest#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * params block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#params SyntheticsTest#params}
     *
     * @stability stable
     */
    readonly params: SyntheticsTestBrowserStepParams[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestBrowserVariable {
    /**
     * Example for the variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#example SyntheticsTest#example}
     *
     * @stability stable
     */
    readonly example?: string;
    /**
     * ID of the global variable to use.
     *
     * This is actually only used (and required) in the case of using a variable of type `global`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#id SyntheticsTest#id}
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * Name of the variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#name SyntheticsTest#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Pattern of the variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#pattern SyntheticsTest#pattern}
     *
     * @stability stable
     */
    readonly pattern?: string;
    /**
     * Type of browser test variable. Valid values are `element`, `email`, `global`, `javascript`, `text`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#type SyntheticsTest#type}
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestConfigVariable {
    /**
     * Example for the variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#example SyntheticsTest#example}
     *
     * @stability stable
     */
    readonly example?: string;
    /**
     * When type = `global`, ID of the global variable to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#id SyntheticsTest#id}
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * Name of the variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#name SyntheticsTest#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Pattern of the variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#pattern SyntheticsTest#pattern}
     *
     * @stability stable
     */
    readonly pattern?: string;
    /**
     * Type of test configuration variable. Valid values are `global`, `text`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#type SyntheticsTest#type}
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestOptionsListMonitorOptions {
    /**
     * Specify a renotification frequency.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#renotify_interval SyntheticsTest#renotify_interval}
     *
     * @stability stable
     */
    readonly renotifyInterval?: number;
}
/**
 * @stability stable
 */
export interface SyntheticsTestOptionsListRetry {
    /**
     * Number of retries needed to consider a location as failed before sending a notification alert.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#count SyntheticsTest#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * Interval between a failed test and the next retry in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#interval SyntheticsTest#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface SyntheticsTestOptionsList {
    /**
     * For SSL test, whether or not the test should allow self signed certificates.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#accept_self_signed SyntheticsTest#accept_self_signed}
     *
     * @stability stable
     */
    readonly acceptSelfSigned?: boolean;
    /**
     * Allows loading insecure content for an HTTP test.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#allow_insecure SyntheticsTest#allow_insecure}
     *
     * @stability stable
     */
    readonly allowInsecure?: boolean;
    /**
     * For API HTTP test, whether or not the test should follow redirects.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#follow_redirects SyntheticsTest#follow_redirects}
     *
     * @stability stable
     */
    readonly followRedirects?: boolean;
    /**
     * Minimum amount of time in failure required to trigger an alert. Default is `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#min_failure_duration SyntheticsTest#min_failure_duration}
     *
     * @stability stable
     */
    readonly minFailureDuration?: number;
    /**
     * Minimum number of locations in failure required to trigger an alert. Default is `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#min_location_failed SyntheticsTest#min_location_failed}
     *
     * @stability stable
     */
    readonly minLocationFailed?: number;
    /**
     * The monitor name is used for the alert title as well as for all monitor dashboard widgets and SLOs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#monitor_name SyntheticsTest#monitor_name}
     *
     * @stability stable
     */
    readonly monitorName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#monitor_priority SyntheticsTest#monitor_priority}.
     *
     * @stability stable
     */
    readonly monitorPriority?: number;
    /**
     * Prevents saving screenshots of the steps.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#no_screenshot SyntheticsTest#no_screenshot}
     *
     * @stability stable
     */
    readonly noScreenshot?: boolean;
    /**
     * How often the test should run (in seconds).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#tick_every SyntheticsTest#tick_every}
     *
     * @stability stable
     */
    readonly tickEvery: number;
    /**
     * monitor_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#monitor_options SyntheticsTest#monitor_options}
     *
     * @stability stable
     */
    readonly monitorOptions?: SyntheticsTestOptionsListMonitorOptions[];
    /**
     * retry block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#retry SyntheticsTest#retry}
     *
     * @stability stable
     */
    readonly retry?: SyntheticsTestOptionsListRetry[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestRequestBasicauth {
    /**
     * Password for authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#password SyntheticsTest#password}
     *
     * @stability stable
     */
    readonly password: string;
    /**
     * Username for authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#username SyntheticsTest#username}
     *
     * @stability stable
     */
    readonly username: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestRequestClientCertificateCert {
    /**
     * Content of the certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#content SyntheticsTest#content}
     *
     * @stability stable
     */
    readonly content: string;
    /**
     * File name for the certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#filename SyntheticsTest#filename}
     *
     * @stability stable
     */
    readonly filename?: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestRequestClientCertificateKey {
    /**
     * Content of the certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#content SyntheticsTest#content}
     *
     * @stability stable
     */
    readonly content: string;
    /**
     * File name for the certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#filename SyntheticsTest#filename}
     *
     * @stability stable
     */
    readonly filename?: string;
}
/**
 * @stability stable
 */
export interface SyntheticsTestRequestClientCertificate {
    /**
     * cert block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#cert SyntheticsTest#cert}
     *
     * @stability stable
     */
    readonly cert: SyntheticsTestRequestClientCertificateCert[];
    /**
     * key block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#key SyntheticsTest#key}
     *
     * @stability stable
     */
    readonly key: SyntheticsTestRequestClientCertificateKey[];
}
/**
 * @stability stable
 */
export interface SyntheticsTestRequestDefinition {
    /**
     * The request body.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#body SyntheticsTest#body}
     *
     * @stability stable
     */
    readonly body?: string;
    /**
     * DNS server to use for DNS tests (`subtype = "dns"`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#dns_server SyntheticsTest#dns_server}
     *
     * @stability stable
     */
    readonly dnsServer?: string;
    /**
     * DNS server port to use for DNS tests.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#dns_server_port SyntheticsTest#dns_server_port}
     *
     * @stability stable
     */
    readonly dnsServerPort?: number;
    /**
     * Host name to perform the test with.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#host SyntheticsTest#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * The HTTP method. Valid values are `GET`, `POST`, `PATCH`, `PUT`, `DELETE`, `HEAD`, `OPTIONS`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#method SyntheticsTest#method}
     *
     * @stability stable
     */
    readonly method?: string;
    /**
     * Determines whether or not to save the response body.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#no_saving_response_body SyntheticsTest#no_saving_response_body}
     *
     * @stability stable
     */
    readonly noSavingResponseBody?: boolean;
    /**
     * Number of pings to use per test for ICMP tests (`subtype = "icmp"`) between 0 and 10.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#number_of_packets SyntheticsTest#number_of_packets}
     *
     * @stability stable
     */
    readonly numberOfPackets?: number;
    /**
     * Port to use when performing the test.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#port SyntheticsTest#port}
     *
     * @stability stable
     */
    readonly port?: number;
    /**
     * This will turn on a traceroute probe to discover all gateways along the path to the host destination.
     *
     * For ICMP tests (`subtype = "icmp"`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#should_track_hops SyntheticsTest#should_track_hops}
     *
     * @stability stable
     */
    readonly shouldTrackHops?: boolean;
    /**
     * Timeout in seconds for the test. Defaults to `60`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#timeout SyntheticsTest#timeout}
     *
     * @stability stable
     */
    readonly timeout?: number;
    /**
     * The URL to send the request to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html#url SyntheticsTest#url}
     *
     * @stability stable
     */
    readonly url?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html datadog_synthetics_test}.
 *
 * @stability stable
 */
export declare class SyntheticsTest extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/synthetics_test.html datadog_synthetics_test} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SyntheticsTestConfig);
    private _deviceIds?;
    /**
     * @stability stable
     */
    get deviceIds(): string[];
    /**
     * @stability stable
     */
    set deviceIds(value: string[]);
    /**
     * @stability stable
     */
    resetDeviceIds(): void;
    /**
     * @stability stable
     */
    get deviceIdsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _locations;
    /**
     * @stability stable
     */
    get locations(): string[];
    /**
     * @stability stable
     */
    set locations(value: string[]);
    /**
     * @stability stable
     */
    get locationsInput(): string[];
    private _message?;
    /**
     * @stability stable
     */
    get message(): string;
    /**
     * @stability stable
     */
    set message(value: string);
    /**
     * @stability stable
     */
    resetMessage(): void;
    /**
     * @stability stable
     */
    get messageInput(): string | undefined;
    /**
     * @stability stable
     */
    get monitorId(): number;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _requestHeaders?;
    /**
     * @stability stable
     */
    get requestHeaders(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set requestHeaders(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetRequestHeaders(): void;
    /**
     * @stability stable
     */
    get requestHeadersInput(): {
        [key: string]: string;
    } | undefined;
    private _requestQuery?;
    /**
     * @stability stable
     */
    get requestQuery(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set requestQuery(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetRequestQuery(): void;
    /**
     * @stability stable
     */
    get requestQueryInput(): {
        [key: string]: string;
    } | undefined;
    private _setCookie?;
    /**
     * @stability stable
     */
    get setCookie(): string;
    /**
     * @stability stable
     */
    set setCookie(value: string);
    /**
     * @stability stable
     */
    resetSetCookie(): void;
    /**
     * @stability stable
     */
    get setCookieInput(): string | undefined;
    private _status;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    set status(value: string);
    /**
     * @stability stable
     */
    get statusInput(): string;
    private _subtype?;
    /**
     * @stability stable
     */
    get subtype(): string;
    /**
     * @stability stable
     */
    set subtype(value: string);
    /**
     * @stability stable
     */
    resetSubtype(): void;
    /**
     * @stability stable
     */
    get subtypeInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): string[];
    /**
     * @stability stable
     */
    set tags(value: string[]);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): string[] | undefined;
    private _type;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string;
    private _apiStep?;
    /**
     * @stability stable
     */
    get apiStep(): SyntheticsTestApiStep[];
    /**
     * @stability stable
     */
    set apiStep(value: SyntheticsTestApiStep[]);
    /**
     * @stability stable
     */
    resetApiStep(): void;
    /**
     * @stability stable
     */
    get apiStepInput(): SyntheticsTestApiStep[] | undefined;
    private _assertion?;
    /**
     * @stability stable
     */
    get assertion(): SyntheticsTestAssertion[];
    /**
     * @stability stable
     */
    set assertion(value: SyntheticsTestAssertion[]);
    /**
     * @stability stable
     */
    resetAssertion(): void;
    /**
     * @stability stable
     */
    get assertionInput(): SyntheticsTestAssertion[] | undefined;
    private _browserStep?;
    /**
     * @stability stable
     */
    get browserStep(): SyntheticsTestBrowserStep[];
    /**
     * @stability stable
     */
    set browserStep(value: SyntheticsTestBrowserStep[]);
    /**
     * @stability stable
     */
    resetBrowserStep(): void;
    /**
     * @stability stable
     */
    get browserStepInput(): SyntheticsTestBrowserStep[] | undefined;
    private _browserVariable?;
    /**
     * @stability stable
     */
    get browserVariable(): SyntheticsTestBrowserVariable[];
    /**
     * @stability stable
     */
    set browserVariable(value: SyntheticsTestBrowserVariable[]);
    /**
     * @stability stable
     */
    resetBrowserVariable(): void;
    /**
     * @stability stable
     */
    get browserVariableInput(): SyntheticsTestBrowserVariable[] | undefined;
    private _configVariable?;
    /**
     * @stability stable
     */
    get configVariable(): SyntheticsTestConfigVariable[];
    /**
     * @stability stable
     */
    set configVariable(value: SyntheticsTestConfigVariable[]);
    /**
     * @stability stable
     */
    resetConfigVariable(): void;
    /**
     * @stability stable
     */
    get configVariableInput(): SyntheticsTestConfigVariable[] | undefined;
    private _optionsList?;
    /**
     * @stability stable
     */
    get optionsList(): SyntheticsTestOptionsList[];
    /**
     * @stability stable
     */
    set optionsList(value: SyntheticsTestOptionsList[]);
    /**
     * @stability stable
     */
    resetOptionsList(): void;
    /**
     * @stability stable
     */
    get optionsListInput(): SyntheticsTestOptionsList[] | undefined;
    private _requestBasicauth?;
    /**
     * @stability stable
     */
    get requestBasicauth(): SyntheticsTestRequestBasicauth[];
    /**
     * @stability stable
     */
    set requestBasicauth(value: SyntheticsTestRequestBasicauth[]);
    /**
     * @stability stable
     */
    resetRequestBasicauth(): void;
    /**
     * @stability stable
     */
    get requestBasicauthInput(): SyntheticsTestRequestBasicauth[] | undefined;
    private _requestClientCertificate?;
    /**
     * @stability stable
     */
    get requestClientCertificate(): SyntheticsTestRequestClientCertificate[];
    /**
     * @stability stable
     */
    set requestClientCertificate(value: SyntheticsTestRequestClientCertificate[]);
    /**
     * @stability stable
     */
    resetRequestClientCertificate(): void;
    /**
     * @stability stable
     */
    get requestClientCertificateInput(): SyntheticsTestRequestClientCertificate[] | undefined;
    private _requestDefinition?;
    /**
     * @stability stable
     */
    get requestDefinition(): SyntheticsTestRequestDefinition[];
    /**
     * @stability stable
     */
    set requestDefinition(value: SyntheticsTestRequestDefinition[]);
    /**
     * @stability stable
     */
    resetRequestDefinition(): void;
    /**
     * @stability stable
     */
    get requestDefinitionInput(): SyntheticsTestRequestDefinition[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
